@@ -11,6 +11,9 @@
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 #
 import os
+import sys
+py_sources_path = os.path.abspath('./src')
+sys.path.insert(0, py_sources_path)
 
 # -- Project information -----------------------------------------------------
 
@@ -23,7 +26,7 @@ copyright = '2020, Mark Taylor'
 author = 'Mark Taylor'
 
 # The full version, including alpha/beta/rc tags
-release = '0.0.4'
+release = '0.0.6'
 
 
 # -- General configuration ---------------------------------------------------
@@ -31,7 +34,9 @@ release = '0.0.4'
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
-extensions = ['recommonmark']
+extensions = ['recommonmark',
+              'sphinx.ext.autodoc',
+              'sphinx.ext.napoleon']
 
 source_suffix = {
     '.rst': 'restructuredtext',
@@ -41,11 +46,21 @@ source_suffix = {
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
 
+# tmarktaylor: The documentation sources are at the project root.
+# Any .md, .rst, or folders at the project root that don't
+# belong in the documentation should be listed here.
+#
+# tmarktaylor: Travis CI Job #28.3 build log of tox.ini docs is finding
+# input files in the .tox tree.
+
+#
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
 # This pattern also affects html_static_path and html_extra_path.
 exclude_patterns = [
-    'project.md', 'tests', '.pytest_cache',
+    'project.md', 'tests', 'src',
+    '.tox',
+    '.pytest_cache',
     '_build', 'Thumbs.db', '.DS_Store'
 ]
 
