@@ -42,21 +42,22 @@ def run_and_pytest(
 
     The PYPI package pytest must be installed separately
     since pytest is not required to install phmdoctest.
-    Use this command:
-        pip install pytest
+    Use this command: ``pip install pytest``
 
     Returns SimulatorStatus object.
     SimulatorStatus.runner_status is the CliRunner.invoke return value.
 
     If an outfile is written or streamed to stdout a copy of it
-    is returned in SimulatorStatus.outfile.
+    is found in simulator_status.runner_status.stdout.
 
-    If calling run_and_pytest() from a pytest file, add the
-    pytest option --capture=tee-sys to the command running
+    If calling run_and_pytest() from a pytest file, try adding the
+    pytest option ``--capture=tee-sys`` to the command running
     pytest on the file.
 
-    For example on a checkout of phmdoctest the command line
-    python -m pytest tests -v --capture=tee-sys
+    For example on a checkout of phmdoctest the command line:
+
+    ``python -m pytest tests -v --capture=tee-sys``
+
     will print the outputs from the subprocess.run() invocations
     of pytest on the --outfile written to the temporary directory.
     A wild guess would be that the subprocess inherited changes
@@ -68,11 +69,11 @@ def run_and_pytest(
             - followed by MARKDOWN_FILE
             - ends with --outfile OUTFILE (if needed)
             - all other options are between MARKDOWN_FILE and --outfile
-            for example:
-            phmdoctest MARKDOWN_FILE --skip FIRST --outfile OUTFILE
+              for example:
+              ``phmdoctest MARKDOWN_FILE --skip FIRST --outfile OUTFILE``
 
         pytest_options
-            List of strings like this: ['--strict', '-v'].
+            List of strings like this: ``['--strict', '-v']``.
             Set to empty list to run pytest with no options.
             Set to None to skip pytest.
 
@@ -80,9 +81,11 @@ def run_and_pytest(
         SimulatorStatus containing runner_status, outfile,
         and pytest_exit_code.
     """
-    # chop off phmdoctest since invoking by a python function call
     assert well_formed_command.startswith('phmdoctest ')
-    command1 = well_formed_command.replace('phmdoctest ', '', 1)
+    # trim off any trailing whitespace
+    command0 = well_formed_command.rstrip()
+    # chop off phmdoctest since invoking by a python function call
+    command1 = command0.replace('phmdoctest ', '', 1)
     # simulate commands that don't write OUTFILE.
     wants_help = '--help' in command1
     wants_version = '--version' in command1
