@@ -26,13 +26,12 @@ def setup_module():
     """Collect Markdown fenced code blocks contents from README.md.
 
     The test cases here must be run in order because they
-    take remove items from readme_blocks defined below.
+    pop items from the list readme_blocks.
 
     This means using a pytest -k KEY more specific than
     "-k test_readme" risks taking the wrong block from the
     iterator readme_blocks causing all subsequent test_readme
     test case to fail.
-
     """
     # test cases below iterate through the blocks.
     global readme_blocks
@@ -79,9 +78,9 @@ def test_report():
     """README report output is same as produced by the command."""
     report_command = next(readme_blocks)
     want = next(readme_blocks)
-    simulator_result = phmdoctest.simulator.run_and_pytest(
+    simulator_status = phmdoctest.simulator.run_and_pytest(
         report_command, pytest_options=None)
-    got = simulator_result.runner_status.stdout
+    got = simulator_status.runner_status.stdout
     verify.a_and_b_are_the_same(want, got)
 
 
@@ -114,7 +113,7 @@ def test_outfile_to_stdout():
     outfile_command2 = next(readme_blocks)
     simulator_status = verify.one_example(
         outfile_command1,
-        want_file_name='doc/test_example2.py',
+        want_file_name=None,
         pytest_options=None
     )
     with open('doc/test_example2.py') as fp:
@@ -124,7 +123,7 @@ def test_outfile_to_stdout():
 
     simulator_status = verify.one_example(
         outfile_command2,
-        want_file_name='doc/test_example2.py',
+        want_file_name=None,
         pytest_options=None
     )
     got2 = simulator_status.runner_status.stdout
@@ -155,25 +154,25 @@ def test_usage():
 
 def test_yaml():
     """Show Markdown example and .travis.yml have the same commands."""
-    example_text = next(readme_blocks)
-    install = '- pip install "." pytest'
-    mkdir = '- mkdir tests/tmp'
-    command = (
-        '- phmdoctest project.md --report'
-        ' --outfile tests/tmp/test_project_readme.py'
-    )
-    test = '- pytest --strict -vv tests'
-    assert install in example_text
-    assert mkdir in example_text
-    assert command in example_text
-    assert test in example_text
+    markdown_example_text = next(readme_blocks)
+    expected = """\
+dist: xenial
+language: python
+sudo: false
 
+matrix:
+  include:
+    - python: 3.5
+      install:
+        - pip install "." pytest
+      script:
+        - mkdir tests/tmp
+        - phmdoctest project.md --report --outfile tests/tmp/test_project_readme.py
+        - pytest --strict -vv tests"""
+    verify.a_and_b_are_the_same(expected, markdown_example_text)
     with open('.travis.yml', 'r', encoding='utf-8') as f:
         travis_text = f.read()
-        assert install in travis_text
-        assert mkdir in travis_text
-        assert command in travis_text
-        assert test in travis_text
+        assert travis_text.startswith(expected)
 
 
 # Developers: Changes here must be mirrored in a fenced code block in README.md.
